---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: feature
assignees: ''

---

---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: feature
assignees: ''

---

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**How important is this feature?** Select from the options below:
• Low - it's an enhancement but not crucial for work
• Medium - can do work without it; but it's important (e.g. to save time or for convenience)
• Important - it's a blocker and can't do work without it

**When will use cases depending on this become relevant?** Select from the options below:
• Short-term - 2-4 weeks
• Mid-term - 2-4 months
• Long-term - 6 months - 1 year

**Additional context**
Add any other context or screenshots about the feature request here.
